@@ -18,7 +18,11 @@ class Rasterizer(ABC):
 
     @abstractmethod
     def rasterize(
-        self, history_frames: np.ndarray, history_agents: List[np.ndarray], agent: Optional[np.ndarray] = None
+        self,
+        history_frames: np.ndarray,
+        history_agents: List[np.ndarray],
+        history_tl_faces: List[np.ndarray],
+        agent: Optional[np.ndarray] = None,
     ) -> np.ndarray:
         pass
 
